diff src/protocols/novell/novell.c @ 11338:17142948653e

[gaim-migrate @ 13551] Change the GAIM_CONV_IM and GAIM_CONV_CHAT enums to GAIM_CONV_TYPE_IM and GAIM_CONV_TYPE_CHAT. This touched A LOT of files. Also combined two oscar header files (one of them was small and dorky). committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Thu, 25 Aug 2005 02:33:44 +0000
parents 90be432e8385
children a26eb48d1953
line wrap: on
line diff
--- a/src/protocols/novell/novell.c	Thu Aug 25 00:27:12 2005 +0000
+++ b/src/protocols/novell/novell.c	Thu Aug 25 02:33:44 2005 +0000
@@ -194,8 +194,8 @@
 		if (user_record) {
 
 			/* Set the title for the conversation */
-			/* XXX - Should this be GAIM_CONV_IM? */
-			gconv =	gaim_find_conversation_with_account(GAIM_CONV_ANY,
+			/* XXX - Should this be GAIM_CONV_TYPE_IM? */
+			gconv =	gaim_find_conversation_with_account(GAIM_CONV_TYPE_ANY,
 														nm_user_record_get_display_id(user_record),
 														(GaimAccount *) user->client_data);
 			if (gconv) {
@@ -1762,7 +1762,7 @@
 							text, imflags,
 							nm_event_get_gmt(event));
 
-				gconv =	gaim_find_conversation_with_account(GAIM_CONV_IM,
+				gconv =	gaim_find_conversation_with_account(GAIM_CONV_TYPE_IM,
 					nm_user_record_get_display_id(user_record),
 					(GaimAccount *) user->client_data);
 				if (gconv) {
@@ -2038,9 +2038,9 @@
 
 	ur = nm_find_user_record(user, nm_event_get_source(event));
 	if (ur) {
 		/* XXX - Should this be GAIM_CONV_IM? */
 		gconv =
-			gaim_find_conversation_with_account(GAIM_CONV_ANY,
+			gaim_find_conversation_with_account(GAIM_CONV_TYPE_ANY,
 												nm_user_record_get_display_id(ur),
 												user->client_data);
 		if (gconv) {
@@ -2038,9 +2038,9 @@
 	ur = nm_find_user_record(user, nm_event_get_source(event));
 	if (ur) {
-		/* XXX - Should this be GAIM_CONV_IM? */
+		/* XXX - Should this be GAIM_CONV_TYPE_IM? */
 		gconv =